"""
客户端游戏模板 — 复制 handler.py 和 renderer.py 到 games/ 目录

注册步骤:
  1. 复制 _template/handler.py → games/your_game_handler.py
  2. 复制 _template/renderer.py → games/your_game_renderer.py
  3. 替换所有 TODO
  4. 在 games/__init__.py 添加:
       from . import your_game_handler
       from . import your_game_renderer
"""



"""客户端游戏模块 — 导入即注册渲染器和处理器"""

from . import world_renderer  # noqa: F401
from . import world_handler   # noqa: F401
from . import wordle_renderer  # noqa: F401
from . import wordle_handler   # noqa: F401
from . import mahjong_renderer  # noqa: F401
from . import mahjong_handler   # noqa: F401
